pub struct MixnodeDetailsByIdentityResponse {
pub identity_key: IdentityKey,
pub mixnode_details: Option<MixNodeDetails>,
}Expand description
Response containing details of a bonded mixnode with the provided identity key.
Fields
identity_key: IdentityKeyThe identity key (base58-encoded ed25519 public key) of the mixnode.
mixnode_details: Option<MixNodeDetails>If there exists a bonded mixnode with the provided identity key, this field contains its detailed information.