QueryMsg

Enum QueryMsg 

pub enum QueryMsg {
Show 56 variants Admin {}, GetContractVersion {}, GetCW2ContractVersion {}, GetRewardingValidatorAddress {}, GetStateParams {}, GetState {}, GetCurrentNymNodeVersion {}, GetNymNodeVersionHistory { limit: Option<u32>, start_after: Option<u32>, }, GetRewardingParams {}, GetEpochStatus {}, GetCurrentIntervalDetails {}, GetMixNodeBonds { limit: Option<u32>, start_after: Option<NodeId>, }, GetMixNodesDetailed { limit: Option<u32>, start_after: Option<NodeId>, }, GetUnbondedMixNodes { limit: Option<u32>, start_after: Option<NodeId>, }, GetUnbondedMixNodesByOwner { owner: String, limit: Option<u32>, start_after: Option<NodeId>, }, GetUnbondedMixNodesByIdentityKey { identity_key: String, limit: Option<u32>, start_after: Option<NodeId>, }, GetOwnedMixnode { address: String, }, GetMixnodeDetails { mix_id: NodeId, }, GetMixnodeRewardingDetails { mix_id: NodeId, }, GetStakeSaturation { mix_id: NodeId, }, GetUnbondedMixNodeInformation { mix_id: NodeId, }, GetBondedMixnodeDetailsByIdentity { mix_identity: IdentityKey, }, GetGateways { start_after: Option<IdentityKey>, limit: Option<u32>, }, GetGatewayBond { identity: IdentityKey, }, GetOwnedGateway { address: String, }, GetPreassignedGatewayIds { start_after: Option<IdentityKey>, limit: Option<u32>, }, GetNymNodeBondsPaged { limit: Option<u32>, start_after: Option<NodeId>, }, GetNymNodesDetailedPaged { limit: Option<u32>, start_after: Option<NodeId>, }, GetUnbondedNymNode { node_id: NodeId, }, GetUnbondedNymNodesPaged { limit: Option<u32>, start_after: Option<NodeId>, }, GetUnbondedNymNodesByOwnerPaged { owner: String, limit: Option<u32>, start_after: Option<NodeId>, }, GetUnbondedNymNodesByIdentityKeyPaged { identity_key: IdentityKey, limit: Option<u32>, start_after: Option<NodeId>, }, GetOwnedNymNode { address: String, }, GetNymNodeDetails { node_id: NodeId, }, GetNymNodeDetailsByIdentityKey { node_identity: IdentityKey, }, GetNodeRewardingDetails { node_id: NodeId, }, GetNodeStakeSaturation { node_id: NodeId, }, GetRoleAssignment { role: Role, }, GetRewardedSetMetadata {}, GetNodeDelegations { node_id: NodeId, start_after: Option<OwnerProxySubKey>, limit: Option<u32>, }, GetDelegatorDelegations { delegator: String, start_after: Option<(NodeId, OwnerProxySubKey)>, limit: Option<u32>, }, GetDelegationDetails { node_id: NodeId, delegator: String, proxy: Option<String>, }, GetAllDelegations { start_after: Option<StorageKey>, limit: Option<u32>, }, GetPendingOperatorReward { address: String, }, GetPendingNodeOperatorReward { node_id: NodeId, }, GetPendingDelegatorReward { address: String, node_id: NodeId, proxy: Option<String>, }, GetEstimatedCurrentEpochOperatorReward { node_id: NodeId, estimated_performance: Performance, estimated_work: Option<WorkFactor>, }, GetEstimatedCurrentEpochDelegatorReward { address: String, node_id: NodeId, estimated_performance: Performance, estimated_work: Option<WorkFactor>, }, GetPendingEpochEvents { limit: Option<u32>, start_after: Option<u32>, }, GetPendingIntervalEvents { limit: Option<u32>, start_after: Option<u32>, }, GetPendingEpochEvent { event_id: EpochEventId, }, GetPendingIntervalEvent { event_id: IntervalEventId, }, GetNumberOfPendingEvents {}, GetSigningNonce { address: String, }, GetKeyRotationState {}, GetKeyRotationId {},
}

Variants



Admin



GetContractVersion

Gets build information of this contract, such as the commit hash used for the build or rustc version.



GetCW2ContractVersion

Gets the stored contract version information that’s required by the CW2 spec interface for migrations.



GetRewardingValidatorAddress

Gets the address of the validator that’s allowed to send rewarding transactions and transition the epoch.



GetStateParams

Gets the contract parameters that could be adjusted in a transaction by the contract admin.



GetState

Gets the current state of the contract.



GetCurrentNymNodeVersion

Get the current expected version of a Nym Node.



GetNymNodeVersionHistory

Get the version history of Nym Node.

Fields

limit: Option<u32>

Controls the maximum number of entries returned by the query. Note that too large values will be overwritten by a saner default.

start_after: Option<u32>

Pagination control for the values returned by the query. Note that the provided value itself will not be used for the response.



GetRewardingParams

Gets the current parameters used for reward calculation.



GetEpochStatus

Gets the status of the current rewarding epoch.



GetCurrentIntervalDetails

Get the details of the current rewarding interval.



GetMixNodeBonds

Gets the basic list of all currently bonded mixnodes.

Fields

limit: Option<u32>

Controls the maximum number of entries returned by the query. Note that too large values will be overwritten by a saner default.

start_after: Option<NodeId>

Pagination control for the values returned by the query. Note that the provided value itself will not be used for the response.



GetMixNodesDetailed

Gets the detailed list of all currently bonded mixnodes.

Fields

limit: Option<u32>

Controls the maximum number of entries returned by the query. Note that too large values will be overwritten by a saner default.

start_after: Option<NodeId>

Pagination control for the values returned by the query. Note that the provided value itself will not be used for the response.



GetUnbondedMixNodes

Gets the basic list of all unbonded mixnodes.

Fields

limit: Option<u32>

Controls the maximum number of entries returned by the query. Note that too large values will be overwritten by a saner default.

start_after: Option<NodeId>

Pagination control for the values returned by the query. Note that the provided value itself will not be used for the response.



GetUnbondedMixNodesByOwner

Gets the basic list of all unbonded mixnodes that belonged to a particular owner.

Fields

owner: String

The address of the owner of the mixnodes used for the query.

limit: Option<u32>

Controls the maximum number of entries returned by the query. Note that too large values will be overwritten by a saner default.

start_after: Option<NodeId>

Pagination control for the values returned by the query. Note that the provided value itself will not be used for the response.



GetUnbondedMixNodesByIdentityKey

Gets the basic list of all unbonded mixnodes that used the particular identity key.

Fields

identity_key: String

The identity key (base58-encoded ed25519 public key) of the mixnode used for the query.

limit: Option<u32>

Controls the maximum number of entries returned by the query. Note that too large values will be overwritten by a saner default.

start_after: Option<NodeId>

Pagination control for the values returned by the query. Note that the provided value itself will not be used for the response.



GetOwnedMixnode

Gets the detailed mixnode information belonging to the particular owner.

Fields

address: String

Address of the mixnode owner to use for the query.



GetMixnodeDetails

Gets the detailed mixnode information of a node with the provided id.

Fields

mix_id: NodeId

Id of the node to query.



GetMixnodeRewardingDetails

Gets the rewarding information of a mixnode with the provided id.

Fields

mix_id: NodeId

Id of the node to query.



GetStakeSaturation

Gets the stake saturation of a mixnode with the provided id.

Fields

mix_id: NodeId

Id of the node to query.



GetUnbondedMixNodeInformation

Gets the basic information of an unbonded mixnode with the provided id.

Fields

mix_id: NodeId

Id of the node to query.



GetBondedMixnodeDetailsByIdentity

Gets the detailed mixnode information of a node given its current identity key.

Fields

mix_identity: IdentityKey

The identity key (base58-encoded ed25519 public key) of the mixnode used for the query.



GetGateways

Gets the basic list of all currently bonded gateways.

Fields

start_after: Option<IdentityKey>

Pagination control for the values returned by the query. Note that the provided value itself will not be used for the response.

limit: Option<u32>

Controls the maximum number of entries returned by the query. Note that too large values will be overwritten by a saner default.



GetGatewayBond

Gets the gateway details of a node given its identity key.

Fields

identity: IdentityKey

The identity key (base58-encoded ed25519 public key) of the gateway used for the query.



GetOwnedGateway

Gets the detailed gateway information belonging to the particular owner.

Fields

address: String

Address of the gateway owner to use for the query.



GetPreassignedGatewayIds

Get the NodeIds of all the legacy gateways that they will get assigned once migrated into NymNodes

Fields

start_after: Option<IdentityKey>

Pagination control for the values returned by the query. Note that the provided value itself will not be used for the response.

limit: Option<u32>

Controls the maximum number of entries returned by the query. Note that too large values will be overwritten by a saner default.



GetNymNodeBondsPaged

Gets the basic list of all currently bonded nymnodes.

Fields

limit: Option<u32>

Controls the maximum number of entries returned by the query. Note that too large values will be overwritten by a saner default.

start_after: Option<NodeId>

Pagination control for the values returned by the query. Note that the provided value itself will not be used for the response.



GetNymNodesDetailedPaged

Gets the detailed list of all currently bonded nymnodes.

Fields

limit: Option<u32>

Controls the maximum number of entries returned by the query. Note that too large values will be overwritten by a saner default.

start_after: Option<NodeId>

Pagination control for the values returned by the query. Note that the provided value itself will not be used for the response.



GetUnbondedNymNode

Gets the basic information of an unbonded nym-node with the provided id.

Fields

node_id: NodeId

Id of the node to query.



GetUnbondedNymNodesPaged

Gets the basic list of all unbonded nymnodes.

Fields

limit: Option<u32>

Controls the maximum number of entries returned by the query. Note that too large values will be overwritten by a saner default.

start_after: Option<NodeId>

Pagination control for the values returned by the query. Note that the provided value itself will not be used for the response.



GetUnbondedNymNodesByOwnerPaged

Gets the basic list of all unbonded nymnodes that belonged to a particular owner.

Fields

owner: String

The address of the owner of the nym-node used for the query

limit: Option<u32>

Controls the maximum number of entries returned by the query. Note that too large values will be overwritten by a saner default.

start_after: Option<NodeId>

Pagination control for the values returned by the query. Note that the provided value itself will not be used for the response.



GetUnbondedNymNodesByIdentityKeyPaged

Gets the basic list of all unbonded nymnodes that used the particular identity key.

Fields

identity_key: IdentityKey

The identity key (base58-encoded ed25519 public key) of the node used for the query.

limit: Option<u32>

Controls the maximum number of entries returned by the query. Note that too large values will be overwritten by a saner default.

start_after: Option<NodeId>

Pagination control for the values returned by the query. Note that the provided value itself will not be used for the response.



GetOwnedNymNode

Gets the detailed nymnode information belonging to the particular owner.

Fields

address: String

Address of the node owner to use for the query.



GetNymNodeDetails

Gets the detailed nymnode information of a node with the provided id.

Fields

node_id: NodeId

Id of the node to query.



GetNymNodeDetailsByIdentityKey

Gets the detailed nym-node information given its current identity key.

Fields

node_identity: IdentityKey

The identity key (base58-encoded ed25519 public key) of the nym-node used for the query.



GetNodeRewardingDetails

Gets the rewarding information of a nym-node with the provided id.

Fields

node_id: NodeId

Id of the node to query.



GetNodeStakeSaturation

Gets the stake saturation of a nym-node with the provided id.

Fields

node_id: NodeId

Id of the node to query.



GetRoleAssignment

Fields

role: Role


GetRewardedSetMetadata



GetNodeDelegations

Gets all delegations associated with particular node

Fields

node_id: NodeId

Id of the node to query.

start_after: Option<OwnerProxySubKey>

Pagination control for the values returned by the query. Note that the provided value itself will not be used for the response.

limit: Option<u32>

Controls the maximum number of entries returned by the query. Note that too large values will be overwritten by a saner default.



GetDelegatorDelegations

Gets all delegations associated with particular delegator

Fields

delegator: String

The address of the owner of the delegations.

start_after: Option<(NodeId, OwnerProxySubKey)>

Pagination control for the values returned by the query. Note that the provided value itself will not be used for the response.

limit: Option<u32>

Controls the maximum number of entries returned by the query. Note that too large values will be overwritten by a saner default.



GetDelegationDetails

Gets delegation information associated with particular mixnode - delegator pair

Fields

node_id: NodeId

Id of the node to query.

delegator: String

The address of the owner of the delegation.

proxy: Option<String>

Entity who made the delegation on behalf of the owner. If present, it’s most likely the address of the vesting contract.



GetAllDelegations

Gets all delegations in the system

Fields

start_after: Option<StorageKey>

Pagination control for the values returned by the query. Note that the provided value itself will not be used for the response.

limit: Option<u32>

Controls the maximum number of entries returned by the query. Note that too large values will be overwritten by a saner default.



GetPendingOperatorReward

Gets the reward amount accrued by the node operator that has not yet been claimed.

Fields

address: String

Address of the operator to use for the query.



GetPendingNodeOperatorReward

Gets the reward amount accrued by the particular mixnode that has not yet been claimed.

Fields

node_id: NodeId

Id of the node to query.



GetPendingDelegatorReward

Gets the reward amount accrued by the particular delegator that has not yet been claimed.

Fields

address: String

Address of the delegator to use for the query.

node_id: NodeId

Id of the node to query.

proxy: Option<String>

Entity who made the delegation on behalf of the owner. If present, it’s most likely the address of the vesting contract.



GetEstimatedCurrentEpochOperatorReward

Given the provided node performance, attempt to estimate the operator reward for the current epoch.

Fields

node_id: NodeId

Id of the node to query.

estimated_performance: Performance

The estimated performance for the current epoch of the given node.

estimated_work: Option<WorkFactor>

The estimated work for the current epoch of the given node.



GetEstimatedCurrentEpochDelegatorReward

Given the provided node performance, attempt to estimate the delegator reward for the current epoch.

Fields

address: String

Address of the delegator to use for the query.

node_id: NodeId

Id of the node to query.

estimated_performance: Performance

The estimated performance for the current epoch of the given node.

estimated_work: Option<WorkFactor>

The estimated work for the current epoch of the given node.



GetPendingEpochEvents

Gets the list of all currently pending epoch events that will be resolved once the current epoch finishes.

Fields

limit: Option<u32>

Controls the maximum number of entries returned by the query. Note that too large values will be overwritten by a saner default.

start_after: Option<u32>

Pagination control for the values returned by the query. Note that the provided value itself will not be used for the response.



GetPendingIntervalEvents

Gets the list of all currently pending interval events that will be resolved once the current interval finishes.

Fields

limit: Option<u32>

Controls the maximum number of entries returned by the query. Note that too large values will be overwritten by a saner default.

start_after: Option<u32>

Pagination control for the values returned by the query. Note that the provided value itself will not be used for the response.



GetPendingEpochEvent

Gets detailed information about a pending epoch event given its id.

Fields

event_id: EpochEventId

The unique id associated with the event.



GetPendingIntervalEvent

Gets detailed information about a pending interval event given its id.

Fields

event_id: IntervalEventId

The unique id associated with the event.



GetNumberOfPendingEvents

Gets the information about the number of currently pending epoch and interval events.



GetSigningNonce

Gets the signing nonce associated with the particular cosmos address.

Fields

address: String

Cosmos address used for the query of the signing nonce.



GetKeyRotationState

Gets the current state config of the key rotation (i.e. starting epoch id and validity duration)



GetKeyRotationId

Gets the current key rotation id